@@ -7,7 +7,7 @@ use File::Spec ();
 
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK};
 BEGIN {
-	$VERSION   = '1.14';
+	$VERSION   = '1.15';
 	@ISA       = 'Exporter';
 	@EXPORT    = 'which';
 	@EXPORT_OK = 'where';
@@ -232,7 +232,7 @@ For other issues, contact the maintainer.
 
 Command line interface to this module.
 
-=iten L<IPC::Cmd>
+=item L<IPC::Cmd>
 
 Comes with a C<can_run> function with slightly different semantics that
 the traditional UNIX where.  It will find executables in the current
